@@ -5,11 +5,14 @@ from debmutate.copyright import CopyrightEditor, NotMachineReadableError
 from lintian_brush.fixer import (
     meets_minimum_certainty,
     trust_package,
+    report_result,
     )
-from lintian_brush.upstream_metadata import (
-    guess_upstream_metadata_items,
+from upstream_ontologist import (
     UpstreamDatum,
     )
+from upstream_ontologist.guess import (
+    guess_upstream_metadata_items,
+    )
 
 
 fields = []
@@ -69,10 +72,14 @@ try:
 except (FileNotFoundError, NotMachineReadableError):
     pass
 
-if len(fields) == 1:
-    print('Set field %s in debian/copyright.' % ', '.join(fields))
-else:
-    print('Set fields %s in debian/copyright.' % ', '.join(fields))
 if achieved_certainty:
-    print('Certainty: %s' %
-          min(achieved_certainty, key=certainty_to_confidence))
+    certainty = min(achieved_certainty, key=certainty_to_confidence)
+else:
+    certainty = None
+
+if len(fields) == 1:
+    report_result('Set field %s in debian/copyright.' % ', '.join(fields),
+                  certainty=certainty)
+else:
+    report_result('Set fields %s in debian/copyright.' % ', '.join(fields),
+                  certainty=certainty)
