@@ -40,17 +40,12 @@ from typing import (
     Callable,
 )
 
-from tqdm import trange
-
 from debian.changelog import Changelog, Version
 
 import breezy.bzr  # noqa: F401
 import breezy.git  # noqa: F401
 from breezy.commit import NullCommitReporter
-try:
-    from breezy.transport import NoSuchFile
-except ImportError:  # breezy < 3.3
-    from breezy.errors import NoSuchFile
+from breezy.transport import NoSuchFile
 from breezy.osutils import is_inside
 from breezy.rename_map import RenameMap
 from breezy.tree import Tree
@@ -61,7 +56,7 @@ from breezy.workspace import reset_tree, check_clean_tree
 from debmutate.reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 132)
+__version__ = (0, 133)
 version_string = ".".join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ["certain", "confident", "likely", "possible", None]
 DEFAULT_MINIMUM_CERTAINTY = "certain"
@@ -427,7 +422,7 @@ class PythonScriptFixer(Fixer):
                 traceback.print_exception(
                     type(e), e, e.__traceback__, file=sys.stderr)
                 raise FixerScriptFailed(
-                    self.script_path, 1, sys.stderr.getvalue())
+                    self.script_path, 1, sys.stderr.getvalue()) from e
             else:
                 retcode = 0
             description = sys.stdout.getvalue()
@@ -498,7 +493,7 @@ class ScriptFixer(Fixer):
                 )
             except OSError as e:
                 if e.errno == errno.ENOMEM:
-                    raise MemoryError
+                    raise MemoryError from e
                 raise
             (description, err) = p.communicate(b"")
             if p.returncode == 2:
@@ -513,24 +508,32 @@ class ScriptFixer(Fixer):
         return parse_script_fixer_output(description.decode("utf-8"))
 
 
-def find_fixers_dir() -> str:
-    """Find the local directory with lintian fixer scripts."""
-    local_dir = os.path.abspath(
-        os.path.join(os.path.dirname(__file__), "..", "fixers"))
-    if os.path.isdir(local_dir):
-        return local_dir
+def data_file_path(name, check=os.path.exists):
+    # There's probably a more Pythonic way of doing this, but
+    # I haven't bothered finding out what it is yet..
+    path = os.path.abspath(os.path.join(
+        os.path.dirname(__file__), "..", name))
+    if check(path):
+        return path
+
     import pkg_resources
 
-    resource_dir = pkg_resources.resource_filename(
-        __name__, "lintian-brush/fixers")
-    if os.path.isdir(resource_dir):
-        return resource_dir
-    # Urgh.
-    local_share_dir = "/usr/local/share/lintian-brush/fixers"
-    if os.path.isdir(local_share_dir):
-        return local_share_dir
+    path = pkg_resources.resource_filename(
+        __name__, f"lintian-brush/{name}")
+    if check(path):
+        return path
 
-    return "/usr/share/lintian-brush/fixers"
+    # Urgh.
+    for b in ['/usr/share/lintian-brush', '/usr/local/share/lintian-brush']:
+        path = os.path.join(b, name)
+        if check(path):
+            return path
+    raise RuntimeError("unable to find data path: %s" % name)
+
+
+def find_fixers_dir() -> str:
+    """Find the local directory with lintian fixer scripts."""
+    return data_file_path("fixers", os.path.isdir)
 
 
 def read_desc_file(
@@ -775,8 +778,7 @@ def _upstream_changes_to_patch(
     except PatchSyntax as e:
         raise FailedPatchManipulation(
             local_tree, patches_directory,
-            "Unable to parse some patches: %s" % e
-        )
+            "Unable to parse some patches: %s" % e) from e
     if len(quilt_patches) > 0:
         raise FailedPatchManipulation(
             local_tree,
@@ -800,7 +802,7 @@ def _upstream_changes_to_patch(
         raise FailedPatchManipulation(
             local_tree, patches_directory,
             "patch path %s already exists\n" % e.args[0]
-        )
+        ) from e
 
     return patch_name, specific_files
 
@@ -854,8 +856,8 @@ def run_lintian_fixer(  # noqa: C901
     try:
         with local_tree.get_file(changelog_path) as f:
             cl = Changelog(f, max_blocks=1)
-    except NoSuchFile:
-        raise NotDebianPackage(local_tree, subpath)
+    except NoSuchFile as e:
+        raise NotDebianPackage(local_tree, subpath) from e
     package = cl.package
     if cl.distributions == "UNRELEASED":
         current_version = cl.version
@@ -1104,6 +1106,7 @@ def run_lintian_fixers(  # noqa: C901
         2. dictionary mapping fixer names for fixers that failed to run to the
            error that occurred
     """
+    from tqdm import trange
     basis_tree = local_tree.basis_tree()
     check_clean_tree(local_tree, basis_tree=basis_tree, subpath=subpath)
     fixers = list(fixers)
@@ -1217,8 +1220,8 @@ def confidence_to_certainty(confidence: Optional[int]) -> str:
         return "unknown"
     try:
         return SUPPORTED_CERTAINTIES[confidence] or "unknown"
-    except IndexError:
-        raise ValueError(confidence)
+    except IndexError as exc:
+        raise ValueError(confidence) from exc
 
 
 def min_certainty(certainties: Sequence[str]) -> str:
