@@ -22,6 +22,7 @@ __all__ = [
     'debianize',
     ]
 
+import asyncio
 import contextlib
 from dataclasses import dataclass, field
 import errno
@@ -29,7 +30,6 @@ from functools import partial
 import json
 import logging
 import os
-import re
 import shutil
 import subprocess
 import sys
@@ -59,10 +59,7 @@ from breezy.commit import NullCommitReporter, PointlessCommit
 from breezy.revision import NULL_REVISION
 from breezy.workingtree import WorkingTree
 
-try:
-    from breezy.transport import FileExists
-except ImportError:
-    from breezy.errors import FileExists
+from breezy.transport import FileExists
 
 from ognibuild import DetailedFailure, UnidentifiedError
 from ognibuild.buildlog import InstallFixer, problem_to_upstream_requirement
@@ -86,11 +83,14 @@ from ognibuild.session.plain import PlainSession
 from ognibuild.session.schroot import SchrootSession
 from ognibuild.requirements import (
     Requirement,
-    CargoCrateRequirement,
-    PythonPackageRequirement,
-    GoPackageRequirement,
     )
 from ognibuild.resolver.apt import AptResolver, AptRequirement
+from ognibuild.upstream import (
+    find_upstream,
+    find_apt_upstream,
+    go_base_name,
+    load_crate_info,
+)
 from ognibuild.vcs import dupe_vcs_tree
 
 from upstream_ontologist.guess import (
@@ -104,6 +104,7 @@ from upstream_ontologist.debian import (
 )
 
 from breezy.plugins.debian import default_orig_dir
+from breezy.plugins.debian.directory import vcs_git_url_to_bzr_url
 from breezy.plugins.debian.merge_upstream import (
     get_tarballs,
     do_import,
@@ -133,13 +134,11 @@ from debmutate.versions import (
     debianize_upstream_version,
 )
 
-
 from . import (
     available_lintian_fixers,
     version_string,
     run_lintian_fixers,
     get_committer,
-    version_string as lintian_brush_version_string,
 )
 from .debbugs import find_archived_wnpp_bugs, find_wnpp_bugs
 from .debhelper import (
@@ -231,7 +230,7 @@ def versions_dict():
         'lintian-brush': lintian_brush.version_string,
         'debmutate': debmutate.version_string,
         'debian': debian.__version__,
-        'ognibuild': ognibuild.version_version,
+        'ognibuild': ognibuild.version_version,  # type: ignore
         'buildlog_consultant': buildlog_consultant.version_string,
         'upstream_ontologist': upstream_ontologist.version_string,
     }
@@ -281,7 +280,8 @@ def default_create_dist(session, tree, package, version, target_dir):
                 return ogni_create_dist(
                     session, tree, target_dir,
                     include_controldir=False,
-                    subdir=(package or "package"))
+                    subdir=(package or "package"),
+                    version=version)
             except DetailedFailure as e:
                 if isinstance(
                         e.error,
@@ -289,7 +289,8 @@ def default_create_dist(session, tree, package, version, target_dir):
                     return ogni_create_dist(
                         session, tree, target_dir,
                         include_controldir=True,
-                        subdir=(package or "package"))
+                        subdir=(package or "package"),
+                        version=version)
                 else:
                     raise
     except NoBuildToolsFound:
@@ -301,15 +302,15 @@ def default_create_dist(session, tree, package, version, target_dir):
             "Build system does not support dist, falling back "
             "to export.")
         return None
-    except SessionSetupFailure as e:
-        raise DistCommandFailed(str(e), 'session-setup-failure')
+    except SessionSetupFailure as exc:
+        raise DistCommandFailed(str(exc), 'session-setup-failure') from exc
     except DistNoTarball as e:
         logging.info("Build system did not create a tarball: %s", e)
         return None
-    except DetailedFailure as e:
-        raise DistCommandFailed(str(e), e.error)
-    except UnidentifiedError as e:
-        raise DistCommandFailed(str(e))
+    except DetailedFailure as exc:
+        raise DistCommandFailed(str(exc), exc.error) from exc
+    except UnidentifiedError as exc:
+        raise DistCommandFailed(str(exc)) from exc
 
 
 def import_upstream_version_from_dist(
@@ -398,6 +399,8 @@ def process_setup_py(es, session, wt, subpath, debian_path, upstream_version,
     # TODO(jelmer): check whether project supports python 3
     source["Build-Depends"] = ensure_some_version(
         source["Build-Depends"], "python3-all")
+    # TODO(Jelmer): Convert pyproject's build-system.requirements to Python
+    # deps
     if buildsystem.build_backend in ("flit.build_api", "flit_core.build_api"):
         source["Build-Depends"] = ensure_some_version(
             source["Build-Depends"], "flit")
@@ -558,18 +561,6 @@ def process_perl_build_tiny(es, session, wt, subpath, debian_path,
     return control
 
 
-def go_base_name(package):
-    (hostname, path) = package.split('/', 1)
-    if hostname == "github.com":
-        hostname = "github"
-    if hostname == "gopkg.in":
-        hostname = "gopkg"
-    path = path.rstrip('/').replace("/", "-")
-    if path.endswith('.git'):
-        path = path[:-4]
-    return (hostname + path).replace("_", "-").lower()
-
-
 def process_golang(es, session, wt, subpath, debian_path, upstream_version,
                    metadata, compat_release, buildsystem, buildsystem_subpath,
                    kickstart_from_dist):
@@ -722,8 +713,8 @@ def process_cargo(es, session, wt, subpath, debian_path, upstream_version,
     import semver
     try:
         desired_version = semver.VersionInfo.parse(upstream_version)
-    except ValueError as e:
-        raise BuildSystemProcessError(buildsystem, str(e), e)
+    except ValueError as exc:
+        raise BuildSystemProcessError(buildsystem, str(exc), exc) from exc
     data = load_crate_info(crate)
     if data is None:
         raise BuildSystemProcessError(
@@ -1078,12 +1069,13 @@ def debianize(  # noqa: C901
                         TemporaryDirectory())
                     dupe_vcs_tree(
                         upstream_vcs_tree, exported_upstream_tree_path)
-                    import_metadata_from_path(exported_upstream_tree_path)
+                    import_metadata_from_path(
+                        os.path.join(exported_upstream_tree_path, subpath))
 
             if (buildsystem_name is None
                     and exported_upstream_tree_path is not None):
                 buildsystem_subpath, buildsystem = get_buildsystem(
-                    exported_upstream_tree_path)
+                    os.path.join(exported_upstream_tree_path, subpath))
                 if buildsystem:
                     buildsystem_name = buildsystem.name
             else:
@@ -1128,11 +1120,7 @@ def debianize(  # noqa: C901
                 raise SourcePackageNameInvalid(source['Source'])
 
             if net_access:
-                import asyncio
-
-                loop = asyncio.get_event_loop()
-
-                wnpp_bugs = loop.run_until_complete(
+                wnpp_bugs = asyncio.run(
                     find_wnpp_bugs_harder(
                         source['Source'], metadata.get('Name')))
             else:
@@ -1211,218 +1199,6 @@ def debianize(  # noqa: C901
     return result
 
 
-@dataclass
-class UpstreamInfo:
-    name: Optional[str]
-    buildsystem: Optional[str] = None
-    branch_url: Optional[str] = None
-    branch_subpath: Optional[str] = None
-    tarball_url: Optional[str] = None
-    version: Optional[str] = None
-    metadata: Dict[str, Any] = field(default_factory=dict)
-
-    def json(self):
-        return {
-            'name': self.name,
-            'buildsystem': self.buildsystem,
-            'branch_url': self.branch_url,
-            'branch_subpath': self.branch_subpath,
-            'tarball_url': self.tarball_url,
-            'version': self.version
-        }
-
-
-def load_crate_info(crate):
-    import urllib.error
-    from urllib.request import urlopen, Request
-    import json
-    http_url = 'https://crates.io/api/v1/crates/%s' % crate
-    headers = {'User-Agent': 'debianize', 'Accept': 'application/json'}
-    http_contents = urlopen(Request(http_url, headers=headers)).read()
-    try:
-        return json.loads(http_contents)
-    except urllib.error.HTTPError as e:
-        if e.code == 404:
-            logging.warning('No crate %r', crate)
-            return None
-        raise
-
-
-def find_python_package_upstream(requirement):
-    import urllib.error
-    from urllib.request import urlopen, Request
-    import json
-    http_url = 'https://pypi.org/pypi/%s/json' % requirement.package
-    headers = {'User-Agent': 'ognibuild', 'Accept': 'application/json'}
-    http_contents = urlopen(
-        Request(http_url, headers=headers)).read()
-    try:
-        pypi_data = json.loads(http_contents)
-    except urllib.error.HTTPError as e:
-        if e.code == 404:
-            logging.warning('No pypi project %r', requirement.package)
-            return None
-        raise
-    upstream_branch = None
-    for name, url in pypi_data['info']['project_urls'].items():
-        if name.lower() in ('github', 'repository'):
-            upstream_branch = url
-    tarball_url = None
-    for url_data in pypi_data['urls']:
-        if url_data.get('package_type') == 'sdist':
-            tarball_url = url_data['url']
-    return UpstreamInfo(
-        branch_url=upstream_branch, branch_subpath='',
-        name='python-%s' % pypi_data['info']['name'],
-        tarball_url=tarball_url)
-
-
-def find_go_package_upstream(requirement):
-    if requirement.package.startswith('github.com/'):
-        return UpstreamInfo(
-            name='golang-%s' % go_base_name(requirement.package),
-            branch_url='https://%s' % '/'.join(
-                requirement.package.split('/')[:3]),
-            branch_subpath='')
-
-
-def find_cargo_crate_upstream(requirement):
-    import semver
-    from debmutate.debcargo import semver_pair
-    data = load_crate_info(requirement.crate)
-    if data is None:
-        return None
-    upstream_branch = data['crate']['repository']
-    name = 'rust-' + data['crate']['name'].replace('_', '-')
-    version = None
-    if requirement.api_version is not None:
-        for version_info in data['versions']:
-            if (not version_info['num'].startswith(
-                        requirement.api_version + '.')
-                    and not version_info['num'] == requirement.api_version):
-                continue
-            if version is None:
-                version = semver.VersionInfo.parse(version_info['num'])
-            else:
-                version = semver.max_ver(
-                    version, semver.VersionInfo.parse(version_info['num']))
-        if version is None:
-            logging.warning(
-                'Unable to find version of crate %s '
-                'that matches API version %s',
-                name, requirement.api_version)
-        else:
-            name += '-' + semver_pair(str(version))
-    return UpstreamInfo(
-        branch_url=upstream_branch, branch_subpath=None,
-        name=name, version=str(version) if version else None,
-        metadata={'X-Cargo-Crate': data['crate']['name']},
-        buildsystem='cargo')
-
-
-def apt_to_cargo_requirement(m, rels):
-    name = m.group(1)
-    api_version = m.group(2)
-    if m.group(3):
-        features = set(m.group(3)[1:].split('-'))
-    else:
-        features = set()
-    if not rels:
-        minimum_version = None
-    elif len(rels) == 1 and rels[0][0] == '>=':
-        minimum_version = Version(rels[0][1]).upstream_version
-    else:
-        logging.warning('Unable to parse Debian version %r', rels)
-        minimum_version = None
-
-    return CargoCrateRequirement(
-        name, api_version=api_version,
-        features=features, minimum_version=minimum_version)
-
-
-def apt_to_python_requirement(m, rels):
-    name = m.group(2)
-    python_version = m.group(1)
-    if not rels:
-        minimum_version = None
-    elif len(rels) == 1 and rels[0][0] == '>=':
-        minimum_version = Version(rels[0][1]).upstream_version
-    else:
-        logging.warning('Unable to parse Debian version %r', rels)
-        minimum_version = None
-    return PythonPackageRequirement(
-        name, python_version=(python_version or None),
-        minimum_version=minimum_version)
-
-
-def apt_to_go_requirement(m, rels):
-    parts = m.group(1).split('-')
-    if parts[0] == 'github':
-        parts[0] = 'github.com'
-    if parts[0] == 'gopkg':
-        parts[0] = 'gopkg.in'
-    if not rels:
-        version = None
-    elif len(rels) == 1 and rels[0][0] == '=':
-        version = Version(rels[0][1]).upstream_version
-    else:
-        logging.warning('Unable to parse Debian version %r', rels)
-        version = None
-    return GoPackageRequirement('/'.join(parts), version=version)
-
-
-BINARY_PACKAGE_UPSTREAM_MATCHERS = [
-    (r'librust-(.*)-([^-+]+)(\+.*?)-dev', apt_to_cargo_requirement),
-    (r'python([0-9.]*)-(.*)', apt_to_python_requirement),
-    (r'golang-(.*)-dev', apt_to_go_requirement),
-]
-
-
-_BINARY_PACKAGE_UPSTREAM_MATCHERS = [
-    (re.compile(r), fn) for (r, fn) in BINARY_PACKAGE_UPSTREAM_MATCHERS]
-
-
-def find_apt_upstream(requirement: AptRequirement) -> Optional[UpstreamInfo]:
-    for option in requirement.relations:
-        for rel in option:
-            for matcher, fn in _BINARY_PACKAGE_UPSTREAM_MATCHERS:
-                m = matcher.fullmatch(rel['name'])
-                if m:
-                    upstream_requirement = fn(
-                        m, [rel['version']] if rel['version'] else [])
-                    return find_upstream(upstream_requirement)
-
-            logging.warning(
-                'Unable to map binary package name %s to upstream',
-                rel['name'])
-    return None
-
-
-def find_or_upstream(requirement: Requirement) -> Optional[UpstreamInfo]:
-    for req in requirement.elements:
-        info = find_upstream(req)
-        if info is not None:
-            return info
-    return None
-
-
-UPSTREAM_FINDER = {
-    'python-package': find_python_package_upstream,
-    'go-package': find_go_package_upstream,
-    'cargo-crate': find_cargo_crate_upstream,
-    'apt': find_apt_upstream,
-    'or': find_or_upstream,
-    }
-
-
-def find_upstream(
-        requirement: Requirement) -> Optional[UpstreamInfo]:  # noqa: C901
-    try:
-        return UPSTREAM_FINDER[requirement.family](requirement)
-    except KeyError:
-        return None
-
-
 class SimpleTrustedAptRepo(object):
 
     def __init__(self, directory):
@@ -1655,7 +1431,9 @@ def main(argv=None):  # noqa: C901
     parser.add_argument(
         "--version", action="version", version="%(prog)s " + version_string
     )
-    parser.add_argument("--compat-release", type=str, help=argparse.SUPPRESS)
+    parser.add_argument(
+        "--compat-release", type=str, help=argparse.SUPPRESS,
+        default=os.environ.get('DEB_COMPAT_RELEASE'))
     parser.add_argument(
         "--verbose", help="be verbose", action="store_true", default=False
     )
@@ -1759,6 +1537,11 @@ def main(argv=None):  # noqa: C901
         help=(
             'Package whatever source will create the named Debian '
             'binary package.'))
+    parser.add_argument(
+        '--log-directory',
+        type=str,
+        default=os.environ.get('LOG_DIRECTORY'),
+        help='Directory to write log files to.')
     parser.add_argument('upstream', nargs='?', type=str)
 
     args = parser.parse_args(argv)
@@ -2011,19 +1794,20 @@ def main(argv=None):  # noqa: C901
                         os.path.join(args.output_directory, cn)
                         for cn in changes_names])
 
+    if debianize_result.vcs_url:
+        target_branch_url = vcs_git_url_to_bzr_url(
+            debianize_result.vcs_url)
+    else:
+        target_branch_url = None
+
     if os.environ.get("SVP_API") == "1":
         with open(os.environ['SVP_RESULT'], "w") as f:
             json.dump({
                 "description": "Debianized package",
-                # TODO(jelmer): Convert from Debian to brz format?
-                "target-branch-url": debianize_result.vcs_url,
+                "target-branch-url": target_branch_url,
                 "versions": versions_dict(),
                 "context": {
                     "wnpp_bugs": debianize_result.wnpp_bugs,
-                    "versions": {
-                        "lintian-brush": lintian_brush_version_string,
-                        "breezy": breezy.version_string,
-                    }
                 }
             }, f)
 
