@@ -842,22 +842,6 @@ class LintianBrushVersion(TestCase):
         package_version = re.match(r'^\d+\.\d+', package_version)[0]
         self.assertEqual(package_version, version_string)
 
-    def test_matches_setup_version(self):
-        if not os.path.exists("setup.py"):
-            self.skipTest(
-                "no setup.py available. "
-                "Running outside of source tree?")
-        # TODO(jelmer): Surely there's a better way of doing this?
-        with open("setup.py", "r") as f:
-            for line in f:
-                m = re.match(r'[ ]*version="(.*)",', line)
-                if m:
-                    setup_version = m.group(1)
-                    break
-            else:
-                raise AssertionError("setup version not found")
-        self.assertEqual(version_string, setup_version)
-
 
 class GetCommitterTests(TestCaseWithTransport):
     def test_git_env(self):
